@@ -16,6 +16,26 @@ logging.basicConfig(level=logging.INFO)
 
 
 class CaproverAPI:
+    class Status:
+        STATUS_ERROR_GENERIC = 1000
+        STATUS_OK = 100
+        STATUS_OK_DEPLOY_STARTED = 101
+        STATUS_OK_PARTIALLY = 102
+        STATUS_ERROR_CAPTAIN_NOT_INITIALIZED = 1001
+        STATUS_ERROR_USER_NOT_INITIALIZED = 1101
+        STATUS_ERROR_NOT_AUTHORIZED = 1102
+        STATUS_ERROR_ALREADY_EXIST = 1103
+        STATUS_ERROR_BAD_NAME = 1104
+        STATUS_WRONG_PASSWORD = 1105
+        STATUS_AUTH_TOKEN_INVALID = 1106
+        VERIFICATION_FAILED = 1107
+        ILLEGAL_OPERATION = 1108
+        BUILD_ERROR = 1109
+        ILLEGAL_PARAMETER = 1110
+        NOT_FOUND = 1111
+        AUTHENTICATION_FAILED = 1112
+        STATUS_PASSWORD_BACK_OFF = 1113
+
     LOGIN_PATH = '/api/v2/login'
     SYSTEM_INFO_PATH = "/api/v2/user/system/info"
     APP_LIST_PATH = "/api/v2/user/apps/appDefinitions"
@@ -61,7 +81,10 @@ class CaproverAPI:
     @staticmethod
     def _check_errors(response: dict):
         description = response.get('description', '')
-        if response['status'] != 100:
+        if response['status'] not in [
+            CaproverAPI.Status.STATUS_OK,
+            CaproverAPI.Status.STATUS_OK_PARTIALLY
+        ]:
             logging.error(description)
             raise Exception(response['description'])
         logging.info(description)
@@ -243,7 +266,7 @@ class CaproverAPI:
                 apps_deployed.append(service_name)
         return CaproverAPI._check_errors(
             {
-                "status": 100,
+                "status": CaproverAPI.Status.STATUS_OK,
                 "description": "Deployed all services in >>{}<<".format(
                     one_click_app_name
                 )
@@ -333,7 +356,7 @@ class CaproverAPI:
                 time.sleep(0.20)
         return {
             "description": "All apps matching pattern deleted",
-            "status": 100
+            "status": CaproverAPI.Status.STATUS_OK
         }
 
     def delete_app(self, app_name, delete_volumes: bool = False):
